Constants
=========

CIE
---

``colour.constants``

.. currentmodule:: colour.constants

.. autosummary::
    :toctree: generated/

    CONSTANT_K_M
    CONSTANT_KP_M

CODATA
------

``colour.constants``

.. currentmodule:: colour.constants

.. autosummary::
    :toctree: generated/

    CONSTANT_AVOGADRO
    CONSTANT_BOLTZMANN
    CONSTANT_LIGHT_SPEED
    CONSTANT_PLANCK

Common
------

``colour.constants``

.. currentmodule:: colour.constants

.. autosummary::
    :toctree: generated/

    PATTERN_FLOATING_POINT_NUMBER
    THRESHOLD_INTEGER
    EPSILON
    DTYPE_INT_DEFAULT
    DTYPE_FLOAT_DEFAULT
    TOLERANCE_ABSOLUTE_DEFAULT
    TOLERANCE_RELATIVE_DEFAULT
    TOLERANCE_ABSOLUTE_TESTS
    TOLERANCE_RELATIVE_TESTS
